#ifndef EFL_UI_CURSOR_IMPL_HH
#define EFL_UI_CURSOR_IMPL_HH

#include "efl_ui_cursor.eo.hh"

namespace efl { namespace ui { 
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Cursor::cursor_get() const
{
   const char * __return_value =  ::efl_ui_cursor_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Cursor::cursor_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type cursor) const
{
   Eina_Bool __return_value =  ::efl_ui_cursor_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(cursor));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Cursor::cursor_style_get() const
{
   const char * __return_value =  ::efl_ui_cursor_style_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Cursor::cursor_style_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type style) const
{
   Eina_Bool __return_value =  ::efl_ui_cursor_style_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(style));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Cursor::cursor_theme_search_enabled_get() const
{
   Eina_Bool __return_value =  ::efl_ui_cursor_theme_search_enabled_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Cursor::cursor_theme_search_enabled_set( ::efl::eolian::in_traits<bool>::type allow) const
{
   Eina_Bool __return_value =  ::efl_ui_cursor_theme_search_enabled_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(allow));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
} } 
namespace eo_cxx {
namespace efl { namespace ui { 
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Cursor::cursor_get() const
{
   const char * __return_value =  ::efl_ui_cursor_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Cursor::cursor_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type cursor) const
{
   Eina_Bool __return_value =  ::efl_ui_cursor_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(cursor));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Cursor::cursor_style_get() const
{
   const char * __return_value =  ::efl_ui_cursor_style_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Cursor::cursor_style_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type style) const
{
   Eina_Bool __return_value =  ::efl_ui_cursor_style_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(style));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Cursor::cursor_theme_search_enabled_get() const
{
   Eina_Bool __return_value =  ::efl_ui_cursor_theme_search_enabled_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Cursor::cursor_theme_search_enabled_set( ::efl::eolian::in_traits<bool>::type allow) const
{
   Eina_Bool __return_value =  ::efl_ui_cursor_theme_search_enabled_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(allow));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline efl::ui::Cursor::operator ::efl::ui::Cursor() const { return *static_cast< ::efl::ui::Cursor const*>(static_cast<void const*>(this)); }
inline efl::ui::Cursor::operator ::efl::ui::Cursor&() { return *static_cast< ::efl::ui::Cursor*>(static_cast<void*>(this)); }
inline efl::ui::Cursor::operator ::efl::ui::Cursor const&() const { return *static_cast< ::efl::ui::Cursor const*>(static_cast<void const*>(this)); }
} } }
#endif
